<?php

class ControllerPaymentBetatransfer extends Controller
{
    private $error = array();

    public function __construct($registry)
    {
        parent::__construct($registry);

        $this->load->language('payment/betatransfer');
        $this->document->setTitle($this->language->get('heading_title'));
    }

    public function index()
    {
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && ($this->validate())) {
            $this->request->post['betatransfer_total'] = str_replace(',', '.', $this->request->post['betatransfer_total']);

            $this->load->model('setting/setting');
            $this->model_setting_setting->editSetting('betatransfer', $this->request->post);
            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->makeUrl('extension/payment'));
        }

        $this->load->model('localisation/geo_zone');
        $this->load->model('localisation/order_status');
        $this->load->model('localisation/language');

        $permission = $this->user->hasPermission('modify', 'payment/betatransfer');

        if (!$permission) {
            $this->error['warning'] = sprintf($this->language->get('error_permission'), $this->language->get('heading_title'));
        }

        if (!empty($this->session->data['success'])) {
            $data['success'] = $this->session->data['success'];
            unset($this->session->data['success']);
        }

        $data = array(
            // Common
            'heading_title' => $this->language->get('heading_title'),
            'button_save' => $this->language->get('button_save'),
            'button_cancel' => $this->language->get('button_cancel'),
            'button_clear' => $this->language->get('button_clear'),

            // Tabs
            'tab_general' => $this->language->get('tab_general'),
            'tab_integration' => $this->language->get('tab_integration'),
            'tab_information' => $this->language->get('tab_information'),

            // Entries
            'entry_geo_zone' => $this->language->get('entry_geo_zone'),
            'entry_sort_order' => $this->language->get('entry_sort_order'),
            'entry_total' => $this->language->get('entry_total'),
            'entry_order_confirm_status' => $this->language->get('entry_order_confirm_status'),
            'entry_order_success_status' => $this->language->get('entry_order_success_status'),
            'entry_order_fail_status' => $this->language->get('entry_order_fail_status'),
            'entry_status' => $this->language->get('entry_status'),
            'entry_token' => $this->language->get('entry_token'),
            'entry_secret' => $this->language->get('entry_secret'),
            'entry_payment_system' => $this->language->get('entry_payment_system'),
            'entry_title' => $this->language->get('entry_title'),
            'entry_callback_url' => $this->language->get('entry_callback_url'),
            'entry_success_url' => $this->language->get('entry_success_url'),
            'entry_fail_url' => $this->language->get('entry_fail_url'),

            // Texts
            'text_all_zones' => $this->language->get('text_all_zones'),
            'text_enabled' => $this->language->get('text_enabled'),
            'text_disabled' => $this->language->get('text_disabled'),

            // Helps
            'help_total' => $this->language->get('help_total'),
            'help_order_confirm_status' => $this->language->get('help_order_confirm_status'),
            'help_order_success_status' => $this->language->get('help_order_success_status'),
            'help_order_fail_status' => $this->language->get('help_order_fail_status'),
            'help_token' => $this->language->get('help_token'),
            'help_secret' => $this->language->get('help_secret'),
            'help_payment_system' => $this->language->get('help_payment_system'),
            'help_title' => $this->language->get('help_title'),

            // Others
            'action' => $this->makeUrl('payment/betatransfer'),
            'cancel' => $this->makeUrl('extension/payment'),
            'geo_zones' => $this->model_localisation_geo_zone->getGeoZones(),
            'order_statuses' => $this->model_localisation_order_status->getOrderStatuses(),
            'has_permission' => $permission,
            'languages' => $this->model_localisation_language->getLanguages(),
            'title_default' => explode(',', $this->language->get('heading_title')),
            'betatransfer_success_url' => HTTPS_CATALOG . 'index.php?route=payment/betatransfer/success',
            'betatransfer_fail_url' => HTTPS_CATALOG . 'index.php?route=payment/betatransfer/fail',
            'betatransfer_callback_url' => HTTPS_CATALOG . 'index.php?route=payment/betatransfer/callback',

            // Errors
            'error_warning' => isset($this->error['warning']) ? $this->error['warning'] : '',
            'error_token' => isset($this->error['error_token']) ? $this->error['error_token'] : '',
            'error_secret' => isset($this->error['error_secret']) ? $this->error['error_secret'] : '',
            'error_payment_system' => isset($this->error['error_payment_system']) ? $this->error['error_payment_system'] : '',
        );

        $data['breadcrumbs'] = array(
            array(
                'href' => $this->makeUrl('common/dashboard'),
                'text' => $this->language->get('text_home')
            ),
            array(
                'href' => $this->makeUrl('extension/payment'),
                'text' => $this->language->get('text_extension')
            ),
            array(
                'href' => $this->makeUrl('payment/betatransfer'),
                'text' => $this->language->get('heading_title')
            ),
        );

        $this->prepareSettings($data);

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('payment/betatransfer.tpl', $data));
    }

    public function prepareSettings(&$data)
    {
        $list_settings = array(
            'betatransfer_geo_zone_id',
            'betatransfer_sort_order',
            'betatransfer_total',
            'betatransfer_order_status_confirm',
            'betatransfer_order_status_success',
            'betatransfer_order_status_fail',
            'betatransfer_token',
            'betatransfer_secret',
            'betatransfer_payment_system',
            'betatransfer_lang_data',
            'betatransfer_status',
        );

        foreach ($list_settings as $setting) {
            if (isset($this->request->post[$setting])) {
                $data[$setting] = $this->request->post[$setting];
            } else {
                $data[$setting] = $this->config->get($setting);
            }
        }

        return $data;
    }

    protected function validate()
    {
        if (!$this->user->hasPermission('modify', 'payment/betatransfer')) {
            $this->error['warning'][] = sprintf($this->language->get('error_permission'), $this->language->get('heading_title'));
            return false;
        }

        if (!isset($this->request->post['betatransfer_token']) || !trim($this->request->post['betatransfer_token'])) {
            $this->error['warning'][] = $this->error['error_token'] = sprintf($this->language->get('error_form'),
                $this->language->get('entry_token'), $this->language->get('tab_integration'));
        }

        if (!isset($this->request->post['betatransfer_secret']) || !trim($this->request->post['betatransfer_secret'])) {
            $this->error['warning'][] = $this->error['error_secret'] = sprintf($this->language->get('error_form'),
                $this->language->get('entry_secret'), $this->language->get('tab_integration'));
        }

        return !$this->error;
    }

    private function makeUrl($route, $url = '')
    {
        return str_replace('&amp;', '&', $this->url->link($route, $url . '&token=' . $this->session->data['token'], 'SSL'));
    }
}
